@@ -10,9 +10,11 @@ TYPECODE = {
 }
 
 UNITS = {
+    "Hz":  1,
     "kHz": 1000,
     "KHz": 1000,
     "MHz": 1000000,
+    "mHz": 1000000,
 }
 
 class SrZip:
